@@ -4,9 +4,9 @@ import pyonr
 import os
 from getpass import getpass
 from bcrypt import checkpw
-from server.app import create_app
+from app import create_app
 
-from notdb_viewer import __version__ as v
+from __init__ import __version__ as v
 
 def main():
    pass
